@@ -1,13 +1,13 @@
 # from .modules.PyQt5.QtWidgets import QApplication
-from .modules.screeninfo.screeninfo import get_monitors
-from .modules.mss import mss
+from modules.screeninfo.screeninfo import get_monitors
+from modules.mss import mss
 from PyQt5.QtWidgets import QApplication
 
 import sys
 
 class DisplayInfo():
     def __init__(self):
-        self.app = QApplication(sys.argv)
+        self.app = None
         # self.screens = app.screens()
         self.scale_factor = []
         self.display_info = []
@@ -15,9 +15,11 @@ class DisplayInfo():
         
 
     def get_scale_factor(self):
+        self.app = QApplication(sys.argv)
         screens = self.app.screens()
         for i, screen in enumerate(screens):
             logical_dpi = screen.logicalDotsPerInch()
+            print(screen, logical_dpi)
             self.scale_factor.append(logical_dpi / 96.0)  # Based on Windows' standard DPI of 96
             # print(f"Monitor {i+1}: Scale Factor = {self.scale_factor}")
         return self.scale_factor
@@ -47,10 +49,10 @@ class DisplayInfo():
 
 
 
-# if __name__ == "__main__":
-#     dis = DisplayInfo()
-#     # dis.print_scale_factors()
-#     # dis.print_screen_info()
-#     print(dis.get_screen_info())
-#     print(dis.get_scale_factor())
+if __name__ == "__main__":
+    dis = DisplayInfo()
+    # dis.print_scale_factors()
+    # dis.print_screen_info()
+    print(dis.get_screen_info())
+    print(dis.get_scale_factor())
     
\ No newline at end of file
